@@ -2,6 +2,26 @@
 
 from django.db import models
 from jsonfield import JSONField
+from django.utils.text import slugify
+
+
+class Banco(models.Model):
+    id = models.AutoField(db_column="banco_id", primary_key=True)
+    nome = models.CharField(db_column="banco_nome", max_length=128)
+    imagem = models.CharField(db_column='banco_imagem', max_length=256)
+    codigo = models.CharField(db_column='banco_codigo', max_length=3)
+
+    class Meta:
+        db_table = u"configuracao\".\"tb_banco"
+        verbose_name = u'Banco'
+        verbose_name_plural = u'Bancos'
+        ordering = ['nome']
+
+    def __unicode__(self):
+        return self.nome
+
+    def natural_key(self):
+        return self.nome
 
 
 class FormaPagamento(models.Model):
@@ -51,6 +71,41 @@ class FormaPagamento(models.Model):
         return self.nome
 
 
+class PagamentoBanco(models.Model):
+
+    id = models.AutoField(db_column="pagamento_banco_id", primary_key=True)
+    agencia = models.CharField(db_column="pagamento_banco_agencia", max_length=11, null=False)
+    numero_conta = models.CharField(db_column="pagamento_banco_conta", max_length=11, null=False)
+    poupanca = models.BooleanField(db_column="pagamento_banco_poupanca", default=True, null=False)
+    operacao = models.CharField(db_column="pagamento_banco_variacao", max_length=10, null=True)
+    favorecido = models.CharField(db_column="pagamento_banco_favorecido", max_length=256)
+    cpf = models.CharField(db_column="pagamento_banco_cpf", max_length=11, null=True)
+    cnpj = models.CharField(db_column="pagamento_banco_cnpj", max_length=14, null=True)
+    ativo = models.BooleanField(db_column="pagamento_banco_ativo", null=False, default=False)
+
+    banco = models.ForeignKey('configuracao.Banco', db_column="banco_id", related_name='bancos_pagamentos')
+    conta = models.ForeignKey('plataforma.Conta', related_name='pagamento_bancos')
+    pagamento = models.ForeignKey('configuracao.FormaPagamento', db_column="pagamento_id", related_name='bancos')
+    contrato = models.ForeignKey("plataforma.Contrato", related_name="pagamento_bancos")
+
+    class Meta:
+        db_table = u"configuracao\".\"tb_pagamento_banco"
+        verbose_name = u'Banco para depósito'
+        verbose_name_plural = u'Bancos para depósito'
+        unique_together = (('banco', 'conta'),)
+
+    def __unicode__(self):
+        return unicode(self.nome)
+
+    def __repr__(self):
+        return slugify(self.nome)
+
+    def save(self, *args, **kwargs):
+        if self.conta and not self.contrato_id:
+            self.contrato_id = self.conta.contrato_id
+        super(PagamentoBanco, self).save(*args, **kwargs)
+
+
 class FormaPagamentoConfiguracao(models.Model):
     """Configuração da forma de pagamento."""
     TIPO_VALOR_FIXO = 'fixo'
